<%@ WebHandler Language="C#" Class="UserCommandProcessHandler" %>

using System;
using System.Web;
using System.IO;
using RasterEdge.Imaging.Basic;
using RasterEdge.XDoc.PDF;
using RasterEdge.WDP;
using RasterEdge.WDP.Manager;
using RasterEdge.XDoc.PDF.HTML5Editor;

public class UserCommandProcessHandler : ProcessHandler
{

    /*
         The SDK will use the following url parameter names, please do not use them
          RECommand, src, filepath, restful
    */
    public override PDFWebDocument FileProcess()
    {
        HttpRequest request = this.Context.Request;

        if (!String.IsNullOrEmpty(request.QueryString["yourtarget"]))
        {
            // load file
            String docid = request.QueryString["yourtarget"];
            if (docid == null)
                return null;

            try
            {
                ViewerSettings viewerSettings = new ViewerSettings(docid);
                //  Get file author from HTTP Request if has.
                if (!String.IsNullOrEmpty(request.QueryString["file_author"]))
                    viewerSettings.FileAuthor = request.QueryString["file_author"];

                //  Load the target PDF file.
                byte[] dataBytes = File.ReadAllBytes(@"C:\\temp\" + docid);

                return REProcessControl.PageLoadFile(request, dataBytes, viewerSettings);
            }
            catch (Exception ex)
            {
                Logger.Log(">>> fail to load the target PDF file. " + ex.Message, LogType.ERROR);
                return null;
            }
        }
        else
        {
            Logger.Log(">>> Unknown load file mode. Load default file defined in Web.config.", LogType.DEBUG);

            // load default file. defined in Web.config
            return REProcessControl.PageLoadFile(request, this.Manager, "", LoadType.Server);
        }
    }

    //  fid: Task ID.
    //  savePath: The abosolute path of the saved PDF file in the task's output folder.
    //  responseMsg: The response message for saving the current document to the task's output folder.
    //               The string value is the relative path of the output file. "Error" means that the saving process is failed.
    public override void SaveFile_OnServer(String fid, String savePath, String responseMsg)
    {
        //  You can process saved pdf document here, like add watermark, ...
        var documentPath = savePath;
        if (!String.IsNullOrEmpty(documentPath))
        {
            Logger.LogFile(fid, "SaveFileOnServer: output file path " + documentPath, LogType.DEBUG);

            //  To verify the output file.
            BaseDocument document = null;
            if (documentPath.EndsWith(".pdf"))
            {
                // document object includes user modified content
                document = new PDFDocument(documentPath);
            }
            if (document != null)
            {
                PDFDocument pdfDoc = document as PDFDocument;
                try
                {
                    //  Post-process
                    PDFMetadata metadata = pdfDoc.GetDescription();
                    metadata.Producer = "RasterEdge EdgePDF";
                    pdfDoc.SetDescription(metadata);
                }
                catch (Exception ex)
                {
                    //  Process error code, and return error information here
                    Logger.LogFile(fid, ex.Message + ". fail to do post-process.", LogType.ERROR);
                }

                //  Get the upload information of the file
                DocUploadInfo docinfo = FileManager.getUploadinfoByFid(fid);
                //  Get your file open url parameters value, if needed.
                String paraFilepathValue = docinfo.GetRequestParameters("yourtarget");
                if (!String.IsNullOrEmpty(paraFilepathValue))
                {
                    try
                    {
                        //  Update the original PDF file.
                        pdfDoc.Save(@"C:\temp\" + paraFilepathValue);
                    }
                    catch (Exception ex)
                    {
                        //  Process error code, and return error information here
                        Logger.LogFile(fid, ex.Message + ". fail to save file to server.", LogType.ERROR);
                    }
                }
                else
                {
                    Logger.LogFile(fid, "no 'yourtarget' in the HTTPRequest.", LogType.INFO);
                }
            }
            else
            {
                Logger.LogFile(fid, "output PDF file is invalid.", LogType.ERROR);
            }
        }
        else
        {
            Logger.LogFile(fid, "fail to save file to server. output file path is null or empty.", LogType.ERROR);
        }
    }
}