<%@ WebHandler Language="C#" Class="UserCommandProcessHandler" %>

using System;
using System.Web;
using RasterEdge.WDP;
using RasterEdge.Imaging.Basic;
using RasterEdge.XDoc.PowerPoint;
using RasterEdge.XDoc.PDF;
using RasterEdge.XDoc.PDF.HTML5Editor;
using System.Drawing;
using System.IO;

public class UserCommandProcessHandler : ProcessHandler
{

    /*
         The SDK will use the following url parameter names, please do not use them
          RECommand, src, filepath, restful
    */
    public override PDFWebDocument FileProcess()
    {
        HttpRequest request = this.Context.Request;

        if (!String.IsNullOrEmpty(request.QueryString["yourtarget"]))
        {
            String docid = request.QueryString["yourtarget"];

            PPTXDocument pptxDoc = new PPTXDocument(System.IO.File.ReadAllBytes(@"C:\\temp\" + docid));

            PDFDocument convertedPDFDoc = convertPPTX2PDF4SlidesInOnePage(pptxDoc);

            return REProcessControl.PageLoadFile(request, this.Manager, convertedPDFDoc, docid);
        }
        else
        {
            Logger.Log(">>> Unknown load file mode. Load default file defined in Web.config.", LogType.DEBUG);

            // load default file. defined in Web.config
            return REProcessControl.PageLoadFile(request, this.Manager, "", LoadType.Server);
        }
    }

    private PDFDocument convertPPTX2PDF4SlidesInOnePage(PPTXDocument pptxDoc)
    {
        //Step 1: convert PPTX to PDF
        MemoryStream tempPDFStream = new MemoryStream();
        pptxDoc.ConvertToDocument(DocumentType.PDF, tempPDFStream);

        //  Step 2: combine pages
        PageArrangeOptions ops = new PageArrangeOptions();
        //  set width of new page to 11 inches
        ops.PageWidth = 11F;
        //  set height of new page to 8.5 inches
        ops.PageHeight = 8.5F;
        //  set page margins in inch
        ops.TopMargin = 1F;
        ops.BottomMargin = 1F;
        ops.LeftMargin = 0.5F;
        ops.RightMargin = 0.5F;

        //  properties to arrange region for each page
        //  1 page per row
        ops.ColumnsPerPage = 2;
        //  2 pages per column
        ops.RowsPerPage = 2;
        //  0.1 inches interval between columns
        ops.ColumnInterval = 0.1F;
        //  0.1 inches interval between rows
        ops.RowInterval = 0.1F;
        //  set fit mode for each page
        ops.FitMode = PageArrangeOptions.PageFitMode.AspectFit;

        //  disable region border
        ops.RegionBorder.Width = 0;
        //  enable page border
        ops.PageBorder.Width = 1;
        ops.PageBorder.Color = Color.Blue;

        MemoryStream outputPDFStream = new MemoryStream();
        PDFDocument.CombinePages(tempPDFStream, outputPDFStream, ops);

        return new PDFDocument(outputPDFStream);
    }

    private PDFDocument convertPPTX2PDF2SlidesInOnePage(PPTXDocument pptxDoc)
    {
        //Step 1: convert PPTX to PDF
        MemoryStream tempPDFStream = new MemoryStream();
        pptxDoc.ConvertToDocument(DocumentType.PDF, tempPDFStream);

        //  Step 2: combine pages
        PageArrangeOptions ops = new PageArrangeOptions();
        //  set width of new page to 8.5 inches
        ops.PageWidth = 8.5F;
        //  set height of new page to 11 inches
        ops.PageHeight = 11F;
        //  set page margins in inch
        ops.TopMargin = 1F;
        ops.BottomMargin = 1F;
        ops.LeftMargin = 0.5F;
        ops.RightMargin = 0.5F;

        //  properties to arrange region for each page
        //  1 page per row
        ops.ColumnsPerPage = 1;
        //  2 pages per column
        ops.RowsPerPage = 2;
        //  0.1 inches interval between columns
        ops.ColumnInterval = 0.1F;
        //  0.1 inches interval between rows
        ops.RowInterval = 0.1F;
        //  set fit mode for each page
        ops.FitMode = PageArrangeOptions.PageFitMode.AspectFit;

        //  disable region border
        ops.RegionBorder.Width = 0;
        //  enable page border
        ops.PageBorder.Width = 1;
        ops.PageBorder.Color = Color.Blue;

        MemoryStream outputPDFStream = new MemoryStream();
        PDFDocument.CombinePages(tempPDFStream, outputPDFStream, ops);

        return new PDFDocument(outputPDFStream);
    }

    

    //  fid: Task ID.
    //  savePath: The abosolute path of the saved PDF file in the task's output folder.
    //  responseMsg: The response message for saving the current document to the task's output folder.
    //               The string value is the relative path of the output file. "Error" means that the saving process is failed.
    public override void SaveFile_OnServer(String fid, String savePath, String responseMsg)
    {
        //  You can process saved pdf document here, like add watermark, ...
        var documentPath = savePath;
        if (!String.IsNullOrEmpty(documentPath))
        {
            Logger.LogFile(fid, "SaveFileOnServer: output file path " + documentPath, LogType.DEBUG);

            //  To verify the output file.
            RasterEdge.Imaging.Basic.BaseDocument document = null;
            if (documentPath.EndsWith(".pdf"))
            {
                // document object includes user modified content
                document = new RasterEdge.XDoc.PDF.PDFDocument(documentPath);
            }
            if (document != null)
            {
                RasterEdge.XDoc.PDF.PDFDocument pdfDoc = document as RasterEdge.XDoc.PDF.PDFDocument;
                try
                {
                    //  Post-process
                    RasterEdge.XDoc.PDF.PDFMetadata metadata = pdfDoc.GetDescription();
                    metadata.Producer = "RasterEdge EdgePDF";
                    pdfDoc.SetDescription(metadata);
                }
                catch (Exception ex)
                {
                    //  Process error code, and return error information here
                    Logger.LogFile(fid, ex.Message + ". fail to do post-process.", LogType.ERROR);
                }

                //  Get the upload information of the file
                RasterEdge.WDP.DocUploadInfo docinfo = RasterEdge.WDP.Manager.FileManager.getUploadinfoByFid(fid);
                //  Get your file open url parameters value, if needed.
                String paraFilepathValue = docinfo.GetRequestParameters("yourtarget");
                if (!String.IsNullOrEmpty(paraFilepathValue))
                {
                    try
                    {
                        pdfDoc.Save(@"C:\temp\" + paraFilepathValue);
                    }
                    catch (Exception ex)
                    {
                        //  Process error code, and return error information here
                        Logger.LogFile(fid, ex.Message + ". fail to save file to server.", LogType.ERROR);
                    }
                }
                else
                {
                    Logger.LogFile(fid, "no 'yourtarget' in the HTTPRequest.", LogType.INFO);
                }
            }
            else
            {
                Logger.LogFile(fid, "output PDF file is invalid.", LogType.ERROR);
            }
        }
        else
        {
            Logger.LogFile(fid, "fail to save file to server. output file path is null or empty.", LogType.ERROR);
        }
    }
}