<%@ WebHandler Language="C#" Class="UserCommandProcessHandler" %>

using System;
using System.Web;
using System.IO;
using RasterEdge.XDoc.PDF;
using RasterEdge.WDP;
using RasterEdge.XDoc.PDF.HTML5Editor;

public class UserCommandProcessHandler : ProcessHandler
{

    /*
         The SDK will use the following url parameter names, please do not use them
          RECommand, src, filepath, restful
    */
    public override PDFWebDocument FileProcess()
    {
        HttpRequest request = this.Context.Request;

        if (!String.IsNullOrEmpty(request.QueryString["yourtarget"]))
        {
            // load file
            String docid = request.QueryString["yourtarget"];
            if (docid == null) docid = "0";
            byte[] dataBytes = System.IO.File.ReadAllBytes(@"C:\\temp\" + docid);
            String fileName = docid;
            return REProcessControl.PageLoadFile(request, this.Manager, dataBytes, fileName);
        }
        else
        {
            Logger.Log(">>> Unknown load file mode. Load default file defined in Web.config.", LogType.DEBUG);

            // load default file. defined in Web.config
            return REProcessControl.PageLoadFile(request, this.Manager, "", LoadType.Server);
        }
    }

    //  fid: Task ID.
    //  savePath: The abosolute path of the saved PDF file in the task's output folder.
    //  responseMsg: The response message for saving the current document to the task's output folder.
    //               The string value is the relative path of the output file. "Error" means that the saving process is failed.
    public override void SaveFile_OnServer(String fid, String savePath, String responseMsg)
    {
        //  You can process saved pdf document here, like add watermark, ...
        var documentPath = savePath;
        if (!String.IsNullOrEmpty(documentPath))
        {
            Logger.LogFile(fid, "SaveFileOnServer: output file path " + documentPath, LogType.DEBUG);

            //  To verify the output file.
            RasterEdge.Imaging.Basic.BaseDocument document = null;
            if (documentPath.EndsWith(".pdf"))
            {
                // document object includes user modified content
                document = new RasterEdge.XDoc.PDF.PDFDocument(documentPath);
            }
            if (document != null)
            {
                RasterEdge.XDoc.PDF.PDFDocument pdfDoc = document as RasterEdge.XDoc.PDF.PDFDocument;
                try
                {
                    //  Post-process
                    RasterEdge.XDoc.PDF.PDFMetadata metadata = pdfDoc.GetDescription();
                    metadata.Producer = "RasterEdge EdgePDF";
                    pdfDoc.SetDescription(metadata);
                }
                catch (Exception ex)
                {
                    //  Process error code, and return error information here
                    Logger.LogFile(fid, ex.Message + ". fail to do post-process.", LogType.ERROR);
                }

                //  Get the upload information of the file
                RasterEdge.WDP.DocUploadInfo docinfo = RasterEdge.WDP.Manager.FileManager.getUploadinfoByFid(fid);
                //  Get your file open url parameters value, if needed.
                String paraFilepathValue = docinfo.GetRequestParameters("yourtarget");
                if (!String.IsNullOrEmpty(paraFilepathValue))
                {
                    try
                    {
                        //  Save file to the original path.
                        ApplyAddonPDFInSaveFunction(pdfDoc, @"C:\temp\" + paraFilepathValue);
                    }
                    catch (Exception ex)
                    {
                        //  Process error code, and return error information here
                        Logger.LogFile(fid, ex.Message + ". fail to save file to server.", LogType.ERROR);
                    }
                }
                else
                {
                    Logger.LogFile(fid, "no 'yourtarget' in the HTTPRequest.", LogType.INFO);
                }
            }
            else
            {
                Logger.LogFile(fid, "output PDF file is invalid.", LogType.ERROR);
            }
        }
        else
        {
            Logger.LogFile(fid, "fail to save file to server. output file path is null or empty.", LogType.ERROR);
        }
    }

    public void ApplyAddonPDFInSaveFunction(PDFDocument pdfDoc, String outputFilePath)
    {
        //  Delete exist file
        if (File.Exists(outputFilePath))
            File.Delete(outputFilePath);

        using (FileStream fs = File.Open(outputFilePath, FileMode.CreateNew, FileAccess.ReadWrite, FileShare.ReadWrite))
        {
            using (MemoryStream ms = new MemoryStream())
            {
                //  Save to file stream.
                pdfDoc.SaveToStream(ms);

                //  Apply password to the output file stream with the specified access permissions.
                PasswordSetting pwSetting = new PasswordSetting("OwnerPassword");
                //  Disable print the document
                pwSetting.IsPrint = false;
                //  Disable modify the contents of the document
                pwSetting.IsModify = false;
                //  Disable copy content from the document
                pwSetting.IsCopy = false;
                //  Disable extract content from the document
                pwSetting.IsExtract = false;
                //  Disable add/modify annotations
                pwSetting.IsAnnot = false;
                //  Disable fill in existing form fields
                pwSetting.IsFillForm = false;
                //  Disable assemble the document
                pwSetting.IsAssemble = false;

                PDFDocument.AddPassword(ms, fs, pwSetting);
            }
        }
    }
}